@@ -5,13 +5,12 @@ from argparse import SUPPRESS, ArgumentDefaultsHelpFormatter, ArgumentParser, Na
 from collections import OrderedDict
 
 from virtualenv.config.convert import get_type
-
-from ..env_var import get_env_var
-from ..ini import IniConfig
+from virtualenv.config.env_var import get_env_var
+from virtualenv.config.ini import IniConfig
 
 
 class VirtualEnvOptions(Namespace):
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         super().__init__(**kwargs)
         self._src = None
         self._sources = {}
@@ -22,7 +21,7 @@ class VirtualEnvOptions(Namespace):
             src = "env var"
         self._sources[key] = src
 
-    def __setattr__(self, key, value):
+    def __setattr__(self, key, value) -> None:
         if getattr(self, "_src", None) is not None:
             self._sources[key] = self._src
         super().__setattr__(key, value)
@@ -36,16 +35,14 @@ class VirtualEnvOptions(Namespace):
             return None
         return max(self.verbose - self.quiet, 0)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"{type(self).__name__}({', '.join(f'{k}={v}' for k, v in vars(self).items() if not k.startswith('_'))})"
 
 
 class VirtualEnvConfigParser(ArgumentParser):
-    """
-    Custom option parser which updates its defaults by checking the configuration files and environmental variables
-    """
+    """Custom option parser which updates its defaults by checking the configuration files and environmental vars."""
 
-    def __init__(self, options=None, env=None, *args, **kwargs):
+    def __init__(self, options=None, env=None, *args, **kwargs) -> None:
         env = os.environ if env is None else env
         self.file_config = IniConfig(env)
         self.epilog_list = []
@@ -57,7 +54,8 @@ class VirtualEnvConfigParser(ArgumentParser):
         super().__init__(*args, **kwargs)
         self._fixed = set()
         if options is not None and not isinstance(options, VirtualEnvOptions):
-            raise TypeError("options must be of type VirtualEnvOptions")
+            msg = "options must be of type VirtualEnvOptions"
+            raise TypeError(msg)
         self.options = VirtualEnvOptions() if options is None else options
         self._interpreter = None
         self._app_data = None
@@ -97,19 +95,20 @@ class VirtualEnvConfigParser(ArgumentParser):
         if namespace is None:
             namespace = self.options
         elif namespace is not self.options:
-            raise ValueError("can only pass in parser.options")
+            msg = "can only pass in parser.options"
+            raise ValueError(msg)
         self._fix_defaults()
-        self.options._src = "cli"
+        self.options._src = "cli"  # noqa: SLF001
         try:
             namespace.env = self.env
             return super().parse_known_args(args, namespace=namespace)
         finally:
-            self.options._src = None
+            self.options._src = None  # noqa: SLF001
 
 
 class HelpFormatter(ArgumentDefaultsHelpFormatter):
-    def __init__(self, prog):
-        super().__init__(prog, max_help_position=32, width=240)
+    def __init__(self, prog, **kwargs) -> None:
+        super().__init__(prog, max_help_position=32, width=240, **kwargs)
 
     def _get_help_string(self, action):
         text = super()._get_help_string(action)
