@@ -11,6 +11,7 @@ import logging
 import os
 import platform
 import re
+import struct
 import sys
 import sysconfig
 import warnings
@@ -18,6 +19,7 @@ from collections import OrderedDict, namedtuple
 from string import digits
 
 VersionInfo = namedtuple("VersionInfo", ["major", "minor", "micro", "releaselevel", "serial"])  # noqa: PYI024
+LOGGER = logging.getLogger(__name__)
 
 
 def _get_path_extensions():
@@ -28,7 +30,7 @@ EXTENSIONS = _get_path_extensions()
 _CONF_VAR_RE = re.compile(r"\{\w+\}")
 
 
-class PythonInfo:  # noqa: PLR0904
+class PythonInfo:
     """Contains information for a Python interpreter."""
 
     def __init__(self) -> None:  # noqa: PLR0915
@@ -43,7 +45,10 @@ class PythonInfo:  # noqa: PLR0904
 
         # this is a tuple in earlier, struct later, unify to our own named tuple
         self.version_info = VersionInfo(*sys.version_info)
-        self.architecture = 64 if sys.maxsize > 2**32 else 32
+        # Use the same implementation as found in stdlib platform.architecture
+        # to account for platforms where the maximum integer is not equal the
+        # pointer size.
+        self.architecture = 32 if struct.calcsize("P") == 4 else 64  # noqa: PLR2004
 
         # Used to determine some file names.
         # See `CPython3Windows.python_zip()`.
@@ -51,6 +56,7 @@ class PythonInfo:  # noqa: PLR0904
 
         self.version = sys.version
         self.os = os.name
+        self.free_threaded = sysconfig.get_config_var("Py_GIL_DISABLED") == 1
 
         # information about the prefix - determines python home
         self.prefix = abs_path(getattr(sys, "prefix", None))  # prefix we think
@@ -117,6 +123,11 @@ class PythonInfo:  # noqa: PLR0904
 
         self.sysconfig_vars = {i: sysconfig.get_config_var(i or "") for i in config_var_keys}
 
+        if "TCL_LIBRARY" in os.environ:
+            self.tcl_lib, self.tk_lib = self._get_tcl_tk_libs()
+        else:
+            self.tcl_lib, self.tk_lib = None, None
+
         confs = {
             k: (self.system_prefix if v is not None and v.startswith(self.prefix) else v)
             for k, v in self.sysconfig_vars.items()
@@ -124,38 +135,113 @@ class PythonInfo:  # noqa: PLR0904
         self.system_stdlib = self.sysconfig_path("stdlib", confs)
         self.system_stdlib_platform = self.sysconfig_path("platstdlib", confs)
         self.max_size = getattr(sys, "maxsize", getattr(sys, "maxint", None))
-        self._creators = None
+
+    @staticmethod
+    def _get_tcl_tk_libs():
+        """
+        Detects the tcl and tk libraries using tkinter.
+
+        This works reliably but spins up tkinter, which is heavy if you don't need it.
+        """
+        tcl_lib, tk_lib = None, None
+        try:
+            import tkinter as tk  # noqa: PLC0415
+        except ImportError:
+            pass
+        else:
+            try:
+                tcl = tk.Tcl()
+                tcl_lib = tcl.eval("info library")
+
+                # Try to get TK library path directly first
+                try:
+                    tk_lib = tcl.eval("set tk_library")
+                    if tk_lib and os.path.isdir(tk_lib):
+                        pass  # We found it directly
+                    else:
+                        tk_lib = None  # Reset if invalid
+                except tk.TclError:
+                    tk_lib = None
+
+                # If direct query failed, try constructing the path
+                if tk_lib is None:
+                    tk_version = tcl.eval("package require Tk")
+                    tcl_parent = os.path.dirname(tcl_lib)
+
+                    # Try different version formats
+                    version_variants = [
+                        tk_version,  # Full version like "8.6.12"
+                        ".".join(tk_version.split(".")[:2]),  # Major.minor like "8.6"
+                        tk_version.split(".")[0],  # Just major like "8"
+                    ]
+
+                    for version in version_variants:
+                        tk_lib_path = os.path.join(tcl_parent, f"tk{version}")
+                        if not os.path.isdir(tk_lib_path):
+                            continue
+                        # Validate it's actually a TK directory
+                        if os.path.exists(os.path.join(tk_lib_path, "tk.tcl")):
+                            tk_lib = tk_lib_path
+                            break
+
+            except tk.TclError:
+                pass
+
+        return tcl_lib, tk_lib
 
     def _fast_get_system_executable(self):
         """Try to get the system executable by just looking at properties."""
-        if self.real_prefix or (  # noqa: PLR1702
-            self.base_prefix is not None and self.base_prefix != self.prefix
-        ):  # if this is a virtual environment
-            if self.real_prefix is None:
-                base_executable = getattr(sys, "_base_executable", None)  # some platforms may set this to help us
-                if base_executable is not None:  # noqa: SIM102 # use the saved system executable if present
-                    if sys.executable != base_executable:  # we know we're in a virtual environment, cannot be us
-                        if os.path.exists(base_executable):
-                            return base_executable
-                        # Python may return "python" because it was invoked from the POSIX virtual environment
-                        # however some installs/distributions do not provide a version-less "python" binary in
-                        # the system install location (see PEP 394) so try to fallback to a versioned binary.
-                        #
-                        # Gate this to Python 3.11 as `sys._base_executable` path resolution is now relative to
-                        # the 'home' key from pyvenv.cfg which often points to the system install location.
-                        major, minor = self.version_info.major, self.version_info.minor
-                        if self.os == "posix" and (major, minor) >= (3, 11):
-                            # search relative to the directory of sys._base_executable
-                            base_dir = os.path.dirname(base_executable)
-                            for base_executable in [
-                                os.path.join(base_dir, exe) for exe in (f"python{major}", f"python{major}.{minor}")
-                            ]:
-                                if os.path.exists(base_executable):
-                                    return base_executable
-            return None  # in this case we just can't tell easily without poking around FS and calling them, bail
         # if we're not in a virtual environment, this is already a system python, so return the original executable
         # note we must choose the original and not the pure executable as shim scripts might throw us off
-        return self.original_executable
+        if not (self.real_prefix or (self.base_prefix is not None and self.base_prefix != self.prefix)):
+            return self.original_executable
+
+        # if this is NOT a virtual environment, can't determine easily, bail out
+        if self.real_prefix is not None:
+            return None
+
+        base_executable = getattr(sys, "_base_executable", None)  # some platforms may set this to help us
+        if base_executable is None:  # use the saved system executable if present
+            return None
+
+        # we know we're in a virtual environment, can not be us
+        if sys.executable == base_executable:
+            return None
+
+        # We're not in a venv and base_executable exists; use it directly
+        if os.path.exists(base_executable):
+            return base_executable
+
+        # Try fallback for POSIX virtual environments
+        return self._try_posix_fallback_executable(base_executable)
+
+    def _try_posix_fallback_executable(self, base_executable):
+        """
+        Try to find a versioned Python binary as fallback for POSIX virtual environments.
+
+        Python may return "python" because it was invoked from the POSIX virtual environment
+        however some installs/distributions do not provide a version-less "python" binary in
+        the system install location (see PEP 394) so try to fallback to a versioned binary.
+
+        Gate this to Python 3.11 as `sys._base_executable` path resolution is now relative to
+        the 'home' key from pyvenv.cfg which often points to the system install location.
+        """
+        major, minor = self.version_info.major, self.version_info.minor
+        if self.os != "posix" or (major, minor) < (3, 11):
+            return None
+
+        # search relative to the directory of sys._base_executable
+        base_dir = os.path.dirname(base_executable)
+        candidates = [f"python{major}", f"python{major}.{minor}"]
+        if self.implementation == "PyPy":
+            candidates.extend(["pypy", "pypy3", f"pypy{major}", f"pypy{major}.{minor}"])
+
+        for candidate in candidates:
+            full_path = os.path.join(base_dir, candidate)
+            if os.path.exists(full_path):
+                return full_path
+
+        return None  # in this case we just can't tell easily without poking around FS and calling them, bail
 
     def install_path(self, key):
         result = self.distutils_install.get(key)
@@ -213,7 +299,9 @@ class PythonInfo:  # noqa: PLR0904
         return self.base_prefix is not None
 
     def sysconfig_path(self, key, config_var=None, sep=os.sep):
-        pattern = self.sysconfig_paths[key]
+        pattern = self.sysconfig_paths.get(key)
+        if pattern is None:
+            return ""
         if config_var is None:
             config_var = self.sysconfig_vars
         else:
@@ -222,13 +310,6 @@ class PythonInfo:  # noqa: PLR0904
             config_var = base
         return pattern.format(**config_var).replace("/", sep)
 
-    def creators(self, refresh=False):  # noqa: FBT002
-        if self._creators is None or refresh is True:
-            from virtualenv.run.plugin.creators import CreatorSelector  # noqa: PLC0415
-
-            self._creators = CreatorSelector.for_interpreter(self)
-        return self._creators
-
     @property
     def system_include(self):
         path = self.sysconfig_path(
@@ -289,17 +370,22 @@ class PythonInfo:  # noqa: PLR0904
 
     @property
     def spec(self):
-        return "{}{}-{}".format(self.implementation, ".".join(str(i) for i in self.version_info), self.architecture)
+        return "{}{}{}-{}".format(
+            self.implementation,
+            ".".join(str(i) for i in self.version_info),
+            "t" if self.free_threaded else "",
+            self.architecture,
+        )
 
     @classmethod
-    def clear_cache(cls, app_data):
+    def clear_cache(cls, cache=None):
         # this method is not used by itself, so here and called functions can import stuff locally
         from virtualenv.discovery.cached_py_info import clear  # noqa: PLC0415
 
-        clear(app_data)
+        clear(cache)
         cls._cache_exe_discovery.clear()
 
-    def satisfies(self, spec, impl_must_match):  # noqa: C901
+    def satisfies(self, spec, impl_must_match):  # noqa: C901, PLR0911
         """Check if a given specification can be satisfied by the this python interpreter instance."""
         if spec.path:
             if self.executable == os.path.abspath(spec.path):
@@ -325,6 +411,9 @@ class PythonInfo:  # noqa: PLR0904
         if spec.architecture is not None and spec.architecture != self.architecture:
             return False
 
+        if spec.free_threaded is not None and spec.free_threaded != self.free_threaded:
+            return False
+
         for our, req in zip(self.version_info[0:3], (spec.major, spec.minor, spec.micro)):
             if req is not None and our is not None and our != req:
                 return False
@@ -334,23 +423,35 @@ class PythonInfo:  # noqa: PLR0904
     _current = None
 
     @classmethod
-    def current(cls, app_data=None):
+    def current(cls, app_data, cache):
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
         """  # noqa: D205
         if cls._current is None:
-            cls._current = cls.from_exe(sys.executable, app_data, raise_on_error=True, resolve_to_host=False)
+            cls._current = cls.from_exe(
+                sys.executable,
+                app_data,
+                cache,
+                raise_on_error=True,
+                resolve_to_host=False,
+            )
         return cls._current
 
     @classmethod
-    def current_system(cls, app_data=None) -> PythonInfo:
+    def current_system(cls, app_data, cache) -> PythonInfo:
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
         """  # noqa: D205
         if cls._current_system is None:
-            cls._current_system = cls.from_exe(sys.executable, app_data, raise_on_error=True, resolve_to_host=True)
+            cls._current_system = cls.from_exe(
+                sys.executable,
+                app_data,
+                cache,
+                raise_on_error=True,
+                resolve_to_host=True,
+            )
         return cls._current_system
 
     def _to_json(self):
@@ -358,8 +459,7 @@ class PythonInfo:  # noqa: PLR0904
         return json.dumps(self._to_dict(), indent=2)
 
     def _to_dict(self):
-        data = {var: (getattr(self, var) if var != "_creators" else None) for var in vars(self)}
-
+        data = {var: getattr(self, var) for var in vars(self)}
         data["version_info"] = data["version_info"]._asdict()  # namedtuple to dictionary
         return data
 
@@ -367,7 +467,8 @@ class PythonInfo:  # noqa: PLR0904
     def from_exe(  # noqa: PLR0913
         cls,
         exe,
-        app_data=None,
+        app_data,
+        cache,
         raise_on_error=True,  # noqa: FBT002
         ignore_cache=False,  # noqa: FBT002
         resolve_to_host=True,  # noqa: FBT002
@@ -375,18 +476,26 @@ class PythonInfo:  # noqa: PLR0904
     ):
         """Given a path to an executable get the python information."""
         # this method is not used by itself, so here and called functions can import stuff locally
-        from virtualenv.discovery.cached_py_info import from_exe  # noqa: PLC0415
+        from virtualenv.discovery.cached_py_info import from_exe as from_exe_cache  # noqa: PLC0415
 
         env = os.environ if env is None else env
-        proposed = from_exe(cls, app_data, exe, env=env, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
+        proposed = from_exe_cache(
+            cls,
+            app_data,
+            exe,
+            env=env,
+            raise_on_error=raise_on_error,
+            ignore_cache=ignore_cache,
+            cache=cache,
+        )
 
         if isinstance(proposed, PythonInfo) and resolve_to_host:
             try:
-                proposed = proposed._resolve_to_system(app_data, proposed)  # noqa: SLF001
+                proposed = proposed._resolve_to_system(app_data, proposed, cache=cache)  # noqa: SLF001
             except Exception as exception:
                 if raise_on_error:
                     raise
-                logging.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
+                LOGGER.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
                 proposed = None
         return proposed
 
@@ -404,7 +513,7 @@ class PythonInfo:  # noqa: PLR0904
         return result
 
     @classmethod
-    def _resolve_to_system(cls, app_data, target):
+    def _resolve_to_system(cls, app_data, target, cache):
         start_executable = target.executable
         prefixes = OrderedDict()
         while target.system_executable is None:
@@ -412,29 +521,29 @@ class PythonInfo:  # noqa: PLR0904
             if prefix in prefixes:
                 if len(prefixes) == 1:
                     # if we're linking back to ourselves accept ourselves with a WARNING
-                    logging.info("%r links back to itself via prefixes", target)
+                    LOGGER.info("%r links back to itself via prefixes", target)
                     target.system_executable = target.executable
                     break
                 for at, (p, t) in enumerate(prefixes.items(), start=1):
-                    logging.error("%d: prefix=%s, info=%r", at, p, t)
-                logging.error("%d: prefix=%s, info=%r", len(prefixes) + 1, prefix, target)
+                    LOGGER.error("%d: prefix=%s, info=%r", at, p, t)
+                LOGGER.error("%d: prefix=%s, info=%r", len(prefixes) + 1, prefix, target)
                 msg = "prefixes are causing a circle {}".format("|".join(prefixes.keys()))
                 raise RuntimeError(msg)
             prefixes[prefix] = target
-            target = target.discover_exe(app_data, prefix=prefix, exact=False)
+            target = target.discover_exe(app_data, prefix=prefix, exact=False, cache=cache)
         if target.executable != target.system_executable:
-            target = cls.from_exe(target.system_executable, app_data)
+            target = cls.from_exe(target.system_executable, app_data, cache)
         target.executable = start_executable
         return target
 
     _cache_exe_discovery = {}  # noqa: RUF012
 
-    def discover_exe(self, app_data, prefix, exact=True, env=None):  # noqa: FBT002
+    def discover_exe(self, app_data, cache, prefix, exact=True, env=None):  # noqa: FBT002
         key = prefix, exact
         if key in self._cache_exe_discovery and prefix:
-            logging.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
+            LOGGER.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
             return self._cache_exe_discovery[key]
-        logging.debug("discover exe for %s in %s", self, prefix)
+        LOGGER.debug("discover exe for %s in %s", self, prefix)
         # we don't know explicitly here, do some guess work - our executable name should tell
         possible_names = self._find_possible_exe_names()
         possible_folders = self._find_possible_folders(prefix)
@@ -442,7 +551,7 @@ class PythonInfo:  # noqa: PLR0904
         env = os.environ if env is None else env
         for folder in possible_folders:
             for name in possible_names:
-                info = self._check_exe(app_data, folder, name, exact, discovered, env)
+                info = self._check_exe(app_data, cache, folder, name, exact, discovered, env)
                 if info is not None:
                     self._cache_exe_discovery[key] = info
                     return info
@@ -450,16 +559,23 @@ class PythonInfo:  # noqa: PLR0904
             info = self._select_most_likely(discovered, self)
             folders = os.pathsep.join(possible_folders)
             self._cache_exe_discovery[key] = info
-            logging.debug("no exact match found, chosen most similar of %s within base folders %s", info, folders)
+            LOGGER.debug("no exact match found, chosen most similar of %s within base folders %s", info, folders)
             return info
         msg = "failed to detect {} in {}".format("|".join(possible_names), os.pathsep.join(possible_folders))
         raise RuntimeError(msg)
 
-    def _check_exe(self, app_data, folder, name, exact, discovered, env):  # noqa: PLR0913
+    def _check_exe(self, app_data, cache, folder, name, exact, discovered, env):  # noqa: PLR0913
         exe_path = os.path.join(folder, name)
         if not os.path.exists(exe_path):
             return None
-        info = self.from_exe(exe_path, app_data, resolve_to_host=False, raise_on_error=False, env=env)
+        info = self.from_exe(
+            exe_path,
+            app_data,
+            cache,
+            resolve_to_host=False,
+            raise_on_error=False,
+            env=env,
+        )
         if info is None:  # ignore if for some reason we can't query
             return None
         for item in ["implementation", "architecture", "version_info"]:
@@ -469,7 +585,7 @@ class PythonInfo:  # noqa: PLR0904
                 if item == "version_info":
                     found, searched = ".".join(str(i) for i in found), ".".join(str(i) for i in searched)
                 executable = info.executable
-                logging.debug("refused interpreter %s because %s differs %s != %s", executable, item, found, searched)
+                LOGGER.debug("refused interpreter %s because %s differs %s != %s", executable, item, found, searched)
                 if exact is False:
                     discovered.append(info)
                 break
@@ -521,10 +637,14 @@ class PythonInfo:  # noqa: PLR0904
         for name in self._possible_base():
             for at in (3, 2, 1, 0):
                 version = ".".join(str(i) for i in self.version_info[:at])
-                for arch in [f"-{self.architecture}", ""]:
-                    for ext in EXTENSIONS:
-                        candidate = f"{name}{version}{arch}{ext}"
-                        name_candidate[candidate] = None
+                mods = [""]
+                if self.free_threaded:
+                    mods.append("t")
+                for mod in mods:
+                    for arch in [f"-{self.architecture}", ""]:
+                        for ext in EXTENSIONS:
+                            candidate = f"{name}{version}{mod}{arch}{ext}"
+                            name_candidate[candidate] = None
         return list(name_candidate.keys())
 
     def _possible_base(self):
@@ -539,7 +659,8 @@ class PythonInfo:  # noqa: PLR0904
         for base in possible_base:
             lower = base.lower()
             yield lower
-            from virtualenv.info import fs_is_case_sensitive  # noqa: PLC0415
+
+            from virtualenv.discovery.info import fs_is_case_sensitive  # noqa: PLC0415
 
             if fs_is_case_sensitive():
                 if base != lower:
