@@ -6,15 +6,17 @@ from pathlib import Path
 
 import pytest
 
+from tests.unit.discovery.util import MockAppData, MockCache
 from virtualenv.discovery.py_info import EXTENSIONS, PythonInfo
 from virtualenv.info import IS_WIN, fs_is_case_sensitive, fs_supports_symlink
 
-CURRENT = PythonInfo.current()
+CURRENT = PythonInfo.current(MockAppData(), MockCache())
 
 
-def test_discover_empty_folder(tmp_path, session_app_data):
+def test_discover_empty_folder(tmp_path):
+    app_data, cache = MockAppData(), MockCache()
     with pytest.raises(RuntimeError):
-        CURRENT.discover_exe(session_app_data, prefix=str(tmp_path))
+        CURRENT.discover_exe(app_data, cache, prefix=str(tmp_path))
 
 
 BASE = (CURRENT.install_path("scripts"), ".")
@@ -26,11 +28,12 @@ BASE = (CURRENT.install_path("scripts"), ".")
 @pytest.mark.parametrize("arch", [CURRENT.architecture, ""])
 @pytest.mark.parametrize("version", [".".join(str(i) for i in CURRENT.version_info[0:i]) for i in range(3, 0, -1)])
 @pytest.mark.parametrize("impl", [CURRENT.implementation, "python"])
-def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog, session_app_data):
+def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog):  # noqa: PLR0913
     caplog.set_level(logging.DEBUG)
+    app_data, cache = MockAppData(), MockCache()
     folder = tmp_path / into
     folder.mkdir(parents=True, exist_ok=True)
-    name = f"{impl}{version}"
+    name = f"{impl}{version}{'t' if CURRENT.free_threaded else ''}"
     if arch:
         name += f"-{arch}"
     name += suffix
@@ -40,7 +43,7 @@ def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog, sessio
     if pyvenv.exists():
         (folder / pyvenv.name).write_text(pyvenv.read_text(encoding="utf-8"), encoding="utf-8")
     inside_folder = str(tmp_path)
-    base = CURRENT.discover_exe(session_app_data, inside_folder)
+    base = CURRENT.discover_exe(app_data, cache, inside_folder)
     found = base.executable
     dest_str = str(dest)
     if not fs_is_case_sensitive():
@@ -51,6 +54,6 @@ def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog, sessio
     assert "get interpreter info via cmd: " in caplog.text
 
     dest.rename(dest.parent / (dest.name + "-1"))
-    CURRENT._cache_exe_discovery.clear()
+    CURRENT._cache_exe_discovery.clear()  # noqa: SLF001
     with pytest.raises(RuntimeError):
-        CURRENT.discover_exe(session_app_data, inside_folder)
+        CURRENT.discover_exe(app_data, cache, inside_folder)
