@@ -6,13 +6,13 @@ from pathlib import Path
 import pytest
 
 
-@pytest.fixture()
-def _mock_registry(mocker):
-    from virtualenv.discovery.windows.pep514 import winreg
+@pytest.fixture
+def _mock_registry(mocker):  # noqa: C901
+    from virtualenv.discovery.windows.pep514 import winreg  # noqa: PLC0415
 
     loc, glob = {}, {}
     mock_value_str = (Path(__file__).parent / "winreg-mock-values.py").read_text(encoding="utf-8")
-    exec(mock_value_str, glob, loc)
+    exec(mock_value_str, glob, loc)  # noqa: S102
     enum_collect = loc["enum_collect"]
     value_collect = loc["value_collect"]
     key_open = loc["key_open"]
@@ -37,13 +37,13 @@ def _mock_registry(mocker):
     mocker.patch.object(winreg, "QueryValueEx", side_effect=_query_value_ex)
 
     class Key:
-        def __init__(self, value):
+        def __init__(self, value) -> None:
             self.value = value
 
         def __enter__(self):
             return self
 
-        def __exit__(self, exc_type, exc_val, exc_tb):  # noqa: U100
+        def __exit__(self, exc_type, exc_val, exc_tb):
             return None
 
     @contextmanager
@@ -65,9 +65,9 @@ def _mock_registry(mocker):
     mocker.patch("os.path.exists", return_value=True)
 
 
-def _mock_pyinfo(major, minor, arch, exe):
+def _mock_pyinfo(major, minor, arch, exe, threaded=False):
     """Return PythonInfo objects with essential metadata set for the given args"""
-    from virtualenv.discovery.py_info import PythonInfo, VersionInfo
+    from virtualenv.discovery.py_info import PythonInfo, VersionInfo  # noqa: PLC0415
 
     info = PythonInfo()
     info.base_prefix = str(Path(exe).parent)
@@ -75,28 +75,31 @@ def _mock_pyinfo(major, minor, arch, exe):
     info.implementation = "CPython"
     info.architecture = arch
     info.version_info = VersionInfo(major, minor, 0, "final", 0)
+    info.free_threaded = threaded
     return info
 
 
-@pytest.fixture()
+@pytest.fixture
 def _populate_pyinfo_cache(monkeypatch):
     """Add metadata to virtualenv.discovery.cached_py_info._CACHE for all (mocked) registry entries"""
-    import virtualenv.discovery.cached_py_info
+    import virtualenv.discovery.cached_py_info  # noqa: PLC0415
 
     # Data matches _mock_registry fixture
+    python_core_path = "C:\\Users\\user\\AppData\\Local\\Programs\\Python"
     interpreters = [
-        ("ContinuumAnalytics", 3, 10, 32, "C:\\Users\\user\\Miniconda3\\python.exe", None),
-        ("ContinuumAnalytics", 3, 10, 64, "C:\\Users\\user\\Miniconda3-64\\python.exe", None),
-        ("PythonCore", 3, 9, 64, "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python36\\python.exe", None),
-        ("PythonCore", 3, 9, 64, "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python36\\python.exe", None),
-        ("PythonCore", 3, 5, 64, "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python35\\python.exe", None),
-        ("PythonCore", 3, 9, 64, "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python36\\python.exe", None),
-        ("PythonCore", 3, 7, 32, "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python37-32\\python.exe", None),
-        ("PythonCore", 3, 12, 64, "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python312\\python.exe", None),
-        ("PythonCore", 2, 7, 64, "C:\\Python27\\python.exe", None),
-        ("PythonCore", 3, 4, 64, "C:\\Python34\\python.exe", None),
-        ("CompanyA", 3, 6, 64, "Z:\\CompanyA\\Python\\3.6\\python.exe", None),
+        ("ContinuumAnalytics", 3, 10, 32, False, "C:\\Users\\user\\Miniconda3\\python.exe"),
+        ("ContinuumAnalytics", 3, 10, 64, False, "C:\\Users\\user\\Miniconda3-64\\python.exe"),
+        ("PythonCore", 3, 9, 64, False, f"{python_core_path}\\Python36\\python.exe"),
+        ("PythonCore", 3, 9, 64, False, f"{python_core_path}\\Python36\\python.exe"),
+        ("PythonCore", 3, 5, 64, False, f"{python_core_path}\\Python35\\python.exe"),
+        ("PythonCore", 3, 9, 64, False, f"{python_core_path}\\Python36\\python.exe"),
+        ("PythonCore", 3, 7, 32, False, f"{python_core_path}\\Python37-32\\python.exe"),
+        ("PythonCore", 3, 12, 64, False, f"{python_core_path}\\Python312\\python.exe"),
+        ("PythonCore", 3, 13, 64, True, f"{python_core_path}\\Python313\\python3.13t.exe"),
+        ("PythonCore", 2, 7, 64, False, "C:\\Python27\\python.exe"),
+        ("PythonCore", 3, 4, 64, False, "C:\\Python34\\python.exe"),
+        ("CompanyA", 3, 6, 64, False, "Z:\\CompanyA\\Python\\3.6\\python.exe"),
     ]
-    for _, major, minor, arch, exe, _ in interpreters:
-        info = _mock_pyinfo(major, minor, arch, exe)
-        monkeypatch.setitem(virtualenv.discovery.cached_py_info._CACHE, Path(info.executable), info)
+    for _, major, minor, arch, threaded, exe in interpreters:
+        info = _mock_pyinfo(major, minor, arch, exe, threaded)
+        monkeypatch.setitem(virtualenv.discovery.cached_py_info._CACHE, Path(info.executable), info)  # noqa: SLF001
