@@ -4,6 +4,7 @@ import sys
 
 import pytest
 
+from tests.unit.discovery.util import MockAppData, MockCache
 from virtualenv.discovery.py_spec import PythonSpec
 
 
@@ -20,16 +21,21 @@ from virtualenv.discovery.py_spec import PythonSpec
         ("python3.12", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python312\\python.exe"),
         ("cpython3.12", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python312\\python.exe"),
         # resolves to highest available version
-        ("python", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python312\\python.exe"),
-        ("cpython", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python312\\python.exe"),
+        ("python", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python313\\python3.13t.exe"),
+        ("cpython", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python313\\python3.13t.exe"),
+        ("python3", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python312\\python.exe"),
+        ("cpython3", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python312\\python.exe"),
         # Non-standard org name
         ("python3.6", "Z:\\CompanyA\\Python\\3.6\\python.exe"),
         ("cpython3.6", "Z:\\CompanyA\\Python\\3.6\\python.exe"),
+        # free-threaded
+        ("3t", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python313\\python3.13t.exe"),
+        ("python3.13t", "C:\\Users\\user\\AppData\\Local\\Programs\\Python\\Python313\\python3.13t.exe"),
     ],
 )
 def test_propose_interpreters(string_spec, expected_exe):
-    from virtualenv.discovery.windows import propose_interpreters
+    from virtualenv.discovery.windows import propose_interpreters  # noqa: PLC0415
 
     spec = PythonSpec.from_string_spec(string_spec)
-    interpreter = next(propose_interpreters(spec=spec, cache_dir=None, env=None))
+    interpreter = next(propose_interpreters(spec, MockAppData(), MockCache(), env=None))
     assert interpreter.executable == expected_exe
